<?php

function recalculate_subcontractor_purchase_orders($task_id)
{
    $result = get_recalculate_subcontractor_purchase_order_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}


function recalculate_material_requisitions($task_id)
{
    $result = get_recalculate_material_requisition_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}

function recalculate_purchase_requisitions($task_id)
{
    $result = get_recalculate_purchase_requisition_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}


function recalculate_vehicle_requisitions($task_id)
{
    $result = get_recalculate_vehicle_request_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}


function recalculate_iou_requests($task_id)
{
    $result = get_recalculate_iou_request_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}


function recalculate_tool_requests($task_id)
{
    $result = get_recalculate_tool_request_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}

function recalculate_tool_issues($task_id)
{
    $result = get_recalculate_tool_issue_task_details($task_id);
    
    save_to_task_costs_rebuild($result, true);
}








?>